include "trainz.gs"

//
// class SP3S1DCC
// brief ServicePack3, Scenario 1 DCC
//

game class SP3S1DCC isclass Scenario
{
  Train consist1;
  bool done = false;
  int savePoint = 0;

  //
  // Load
  //

  bool Load(string data)
  {
    if(data and data.size())
    {
      savePoint = Str.UnpackInt(data);
      Interface.Load(data);
      Interface.SetScore(Interface.GetScore());
    }
    else
    {
      Interface.AdjustScore(1000);  
    }

    //
    // load the map
    //
    if(!World.LoadMap(World.FindKUID("highland_valley")))
    {
      return false;
    }

    //
    // load the consist spec
    //
    KUID[] consist1Spec = new KUID[0];

    consist1Spec[0] = World.FindKUID("f7_sfred");
    consist1Spec[1] = World.FindKUID("atsf_chair");
    consist1Spec[2] = consist1Spec[1];
    consist1Spec[3] = World.FindKUID("atsf_baggage");

    switch(savePoint)
    {
      case 1 :
        consist1 = World.CreateTrain(consist1Spec, "GWMARK", true);
        break;
      case 2 :
        consist1 = World.CreateTrain(consist1Spec, "HVMARK", true);
        break;
      default :
        consist1 = World.CreateTrain(consist1Spec, "START", true);
    }

    if(!consist1) return false;

    consist1.SetFloatingLimit(Train.KPH_TO_MPS * 10, true);
    consist1.GetFrontmostLocomotive().SetHasDriver(true);
    consist1.SetDecouplingMask(Vehicle.COUPLE_NONE);
    consist1.SetCouplingMask(Vehicle.COUPLE_NONE);

    return true;
  }

  //
  // Save
  //

  string Save()
  {
    return savePoint + " " + Interface.Save();
  }

  void TrainDerailed(int trainId) 
  {
    if(!done)
    {
      Interface.SetObjective("Train derailed", "bad.tga");
      Interface.LogResult("Train derailed - Scenario failed");
      Interface.SetResults();
      World.EndScenario(20);  
      done = true;
    }
  }

  void TrainCollided(int trainId) 
  {
    Interface.SetObjective("Train collision", "bad.tag");
    Interface.LogResult("Train collision - Scenario failed");
    Interface.SetResults();
    World.EndScenario(20);  
  }

  void TrainSpeedingFine() 
  {
    Interface.AdjustScore(-10);  
  }

  void TrainBadCouple(int vehicleId)
  {
    Interface.AdjustScore(-200);  
  }

  //
  // main thread
  //

  thread void main(void)
  {
    Message msg;

    Monitor();

    Interface.SetScore(Interface.GetScore());

    ///////////////////////////////////////////////////////////////////////////
    //
    // load our consist specs
    //
    ///////////////////////////////////////////////////////////////////////////

    KUID[] consist2Spec = new KUID[0];

    consist2Spec[0] = World.FindKUID("cflow_fert");
    consist2Spec[1] = consist2Spec[0];

    KUID[] consist3Spec = new KUID[0];

    consist3Spec[0] = World.FindKUID("prr_fm_tuscan");
    consist3Spec[1] = World.FindKUID("40ft_boxcar");

    KUID[] consist4Spec = new KUID[0];

    consist4Spec[0] = World.FindKUID("cflow_fert");
    consist4Spec[1] = World.FindKUID("prr_fm_tuscan");
    consist4Spec[2] = consist4Spec[0];
    consist4Spec[3] = World.FindKUID("50ft_boxcar");
    consist4Spec[4] = consist4Spec[3];
    consist4Spec[5] = consist4Spec[3];
    consist4Spec[6] = consist4Spec[1];
    consist4Spec[7] = consist4Spec[6];
    consist4Spec[8] = consist4Spec[3];
    consist4Spec[9] = consist4Spec[6];

    KUID[] consist5Spec = new KUID[0];

    consist5Spec[0] = World.FindKUID("f7_sfred");

    KUID[] consist6Spec = new KUID[0];

    consist6Spec[0] = World.FindKUID("sd40_2_santafe");

    KUID[] consist7Spec = new KUID[0];

    consist7Spec[0] = World.FindKUID("4bhopper_il_coal_full");
    consist7Spec[1] = consist7Spec[0];
    consist7Spec[2] = consist7Spec[0];
    consist7Spec[3] = consist7Spec[0];
    consist7Spec[4] = World.FindKUID("prr_fm_tuscan");
    consist7Spec[5] = World.FindKUID("50ft_boxcar");
    consist7Spec[6] = consist7Spec[5];
    consist7Spec[7] = consist7Spec[5];

    KUID[] consist8Spec = new KUID[0];

    consist8Spec[0] = World.FindKUID("prr_fm_tuscan");
    consist8Spec[1] = consist8Spec[0];

    KUID[] consist9Spec = new KUID[0];

    consist9Spec[0] = World.FindKUID("sd40_2_santafe");
    consist9Spec[1] = World.FindKUID("pdhc_babyruth");
    consist9Spec[2] = consist9Spec[1];
    consist9Spec[3] = World.FindKUID("60ft_boxcar");
    consist9Spec[4] = World.FindKUID("gatx_pennsalt");
    consist9Spec[5] = consist9Spec[4];
    consist9Spec[6] = consist9Spec[4];
    consist9Spec[7] = World.FindKUID("50ft_boxcar");
    consist9Spec[8] = consist9Spec[7];
    consist9Spec[9] = consist9Spec[7];

    KUID[] consist10Spec = new KUID[0];

    consist10Spec[0] = World.FindKUID("sd40_2_bn");
    consist10Spec[1] = consist10Spec[0];
    consist10Spec[2] = World.FindKUID("4bhopper_il_coal_full");
    consist10Spec[3] = consist10Spec[2];
    consist10Spec[4] = consist10Spec[2];
    consist10Spec[5] = consist10Spec[2];
    consist10Spec[6] = consist10Spec[2];
    consist10Spec[7] = consist10Spec[2];

    KUID[] consist12Spec = new KUID[0];

    consist12Spec[0] = World.FindKUID("40ft_boxcar");

    KUID[] consist13Spec = new KUID[0];

    consist13Spec[0] = World.FindKUID("f7_sfred");
    consist13Spec[1] = World.FindKUID("atsf_baggage");
    consist13Spec[2] = World.FindKUID("atsf_chair");
    consist13Spec[3] = consist13Spec[2];
    consist13Spec[4] = consist13Spec[2];
    consist13Spec[5] = consist13Spec[2];
    consist13Spec[6] = consist13Spec[1];

    KUID[] consist14Spec = new KUID[0];
  
    consist14Spec[0] = World.FindKUID("f7_sfred");
    consist14Spec[1] = World.FindKUID("atsf_chair");
    consist14Spec[2] = consist14Spec[1];
    consist14Spec[3] = consist14Spec[1];
    consist14Spec[4] = consist14Spec[1];
    consist14Spec[5] = World.FindKUID("atsf_baggage");

    ///////////////////////////////////////////////////////////////////////////
    //
    // load our triggers
    //
    ///////////////////////////////////////////////////////////////////////////

    Trigger tgTurntable = cast<Trigger> Router.GetGameObject("Turntable Trigger");

    if(!tgTurntable)
    {
      Interface.Log("error loading trigger objects");
      return;
    }

    ///////////////////////////////////////////////////////////////////////////
    //
    // CREATE OUR SIGNAL BEHAVIOURS
    //
    ///////////////////////////////////////////////////////////////////////////

    SignalBehaviour signal1NE = new SignalBehaviour();
    signal1NE.SetDefaults();

    signal1NE.warning.objective = "Wait for clear signal.\n\nPress '1' to switch to internal camera.\nPress '2' to return to external camera.";
    signal1NE.warning.icon = "pause.tga";
    signal1NE.runred.alert = "Signal passed at danger, emergency penalty";
    signal1NE.runred.icon = "bad.tga";
    signal1NE.done.icon = "play.tga";
    signal1NE.done.objective = "";

    SignalBehaviour signalBehaviour = new SignalBehaviour();
    signalBehaviour.SetDefaults();

    signalBehaviour.warning.objective = "Wait to meet 9353";
    signalBehaviour.warning.icon = "pause.tga";
    signalBehaviour.runred.alert = "Signal passed at danger, move train back!";
    signalBehaviour.runred.icon = "bad.tga";
    signalBehaviour.lockControlsOnRed = false;
    signalBehaviour.done.icon = "play.tga";

    ///////////////////////////////////////////////////////////////////////////
    //
    // CREATE OUR STATION BEHAVIOUR
    //
    ///////////////////////////////////////////////////////////////////////////

    StationBehaviour stationBehaviour = new StationBehaviour();
    stationBehaviour.SetDefaults();

    stationBehaviour.warning.icon = "stop.tga";
    stationBehaviour.overrun.icon = "bad.tga";
    stationBehaviour.reverse.icon = "bad.tga";
    stationBehaviour.mwstopped.icon = "bad.tga";
    stationBehaviour.stopped.icon = "pause.tga";
    stationBehaviour.stopped.wav = "bell.wav";
    //stationBehaviour.done.icon = "play.tga";
    stationBehaviour.done.wav = "buzzer.wav";

    stationBehaviour.major = "Play2DSound";
    stationBehaviour.minor = "all_aboard.wav";
    stationBehaviour.delay = 15;

    ///////////////////////////////////////////////////////////////////////////
    //
    // branch to our save point
    //
    ///////////////////////////////////////////////////////////////////////////

    if(savePoint == 1) goto greenwood;
    if(savePoint == 2) goto highlandValley;

    ///////////////////////////////////////////////////////////////////////////
    //
    // create our trains
    //
    ///////////////////////////////////////////////////////////////////////////

    World.SetCamera(consist1, World.CAMERA_EXTERNAL);
    World.SetCameraAngle(89, -21, 55.0);

    Train consist2 = World.CreateTrain(consist2Spec, "Lumby Elevator", true);
    Train consist3 = World.CreateTrain(consist3Spec, "Lumby Siding", true);
    Train consist4, consist5, consist6, consist7, consist8, consist9, consist10, consist11, consist12, consist13, consist14;
    Train decoupledTrain;

    consist2.ShowInConsistMenu(false);
    consist3.ShowInConsistMenu(false);

    consist2.SetAutopilotMode(Train.CONTROL_SCRIPT);
    consist3.SetAutopilotMode(Train.CONTROL_SCRIPT);

    consist2.SetHandBrake(true);
    consist3.SetHandBrake(true);

    ///////////////////////////////////////////////////////////////////////////
    //
    // TRAIN TRAVELS FROM START TO STOP AT LUMBY...
    //
    ///////////////////////////////////////////////////////////////////////////

    Navigate.Signal(me, consist1, "1NE", "Awaiting dispatchers clearance", "START S1", Math.Rand(20.0, 30.0), "START S1", signal1NE);
    Interface.SetObjective("Proceed to Lumby Pass.\n\nPress '.' to increase throttle.\nPress ',' to decrease throttle.\nPress '/' to stop.", "play.tga");

    Navigate.LockJunction("LX2 NW", Junction.DIRECTION_LEFT, false);
    Navigate.LockJunction("LX2 SE", Junction.DIRECTION_LEFT, false);

    Navigate.SetSignal("99X", Signal.YELLOW, "");
    Navigate.SetSignal("101", Signal.YELLOW, "");
    Navigate.SetSignal("483", Signal.YELLOW, "");

    stationBehaviour.stopped.objective = "Await guard's right of way.\n\nPress F1 to toggle camera panel.\nPress Space to toggle the consist bar.\nPress Ctrl-Space to toggle all.";
    Navigate.Station(me, consist1, "Lumby", "Lumby Warn", "Lumby Trigger", "Lumby Overrun", "Start Reverse", stationBehaviour, 20, 30);
    stationBehaviour.stopped.objective = "Await guard's right of way.";

    ///////////////////////////////////////////////////////////////////////////
    //
    // TRAIN TRAVELS FROM LUMBY TO STOP AT GREENWOOD...
    //
    ///////////////////////////////////////////////////////////////////////////

    Sleep(4);

    Interface.SetObjective("Proceed to Greenwood\n\nYour current score is " + Interface.GetScore() + ".\nThis is shown in red to the left.\nPoints are deducted for speeding and other infringements.", "play.tga");

    // switch some juncitons.
    Navigate.LockJunction("LX3 NE", Junction.DIRECTION_RIGHT, false);
    Navigate.LockJunction("LX3 SW", Junction.DIRECTION_RIGHT, false);
    Navigate.LockJunction("X2 SE", Junction.DIRECTION_RIGHT, false);
    Navigate.LockJunction("X2 NE", Junction.DIRECTION_LEFT, false);
    Navigate.LockJunction("Greenwood Team Track", Junction.DIRECTION_LEFT, false);

    // wait on the Done Lumby Trigger so we can clean up some consists.

    Navigate.OnTrigger(me, consist1, "Done Lumby", Navigate.TRIGGER_ENTER);

    World.DeleteTrain(consist2);
    World.DeleteTrain(consist3);

greenwood:

    if(savePoint == 0) Sleep(1);

    consist4 = World.CreateTrain(consist4Spec, "Class 1", false);
    consist4.ShowInConsistMenu(false);
    consist4.SetAutopilotMode(Train.CONTROL_SCRIPT);
    consist4.SetHandBrake(true);

    if(savePoint == 0) Sleep(2.5);

    consist6 = World.CreateTrain(consist6Spec, "Loco 1", true);
    consist6.ShowInConsistMenu(false);
    consist6.SetAutopilotMode(Train.CONTROL_SCRIPT);
    consist6.SetHandBrake(true);

    if(savePoint == 0) Sleep(2.5);

    consist7 = World.CreateTrain(consist7Spec, "Class 2", true);
    consist7.ShowInConsistMenu(false);
    consist7.SetAutopilotMode(Train.CONTROL_SCRIPT);
    consist7.SetHandBrake(true);

    Navigate.LockJunction("Afton Branch", Junction.DIRECTION_LEFT, false);
    Navigate.LockJunction("Greenwood Terminal", Junction.DIRECTION_LEFT, false);
    Navigate.LockJunction("X1ASE", Junction.DIRECTION_LEFT, false);
    Navigate.LockJunction("X1ANW", Junction.DIRECTION_LEFT, false);

    Navigate.LockJunction("Cominco Loads North", Junction.DIRECTION_LEFT, false);
    Navigate.LockJunction("Cominco Coal North", Junction.DIRECTION_LEFT, false);
    Navigate.LockJunction("Robbins North", Junction.DIRECTION_LEFT, false);
    Navigate.LockJunction("Robbins Team track", Junction.DIRECTION_LEFT, false);
    Navigate.LockJunction("Robbins South", Junction.DIRECTION_RIGHT, false);

    if(savePoint == 0)
    {
      stationBehaviour.major = null;
      stationBehaviour.stopped.wav = "Large Terminal.wav";
      Navigate.Station(me, consist1, "Greenwood", "Greenwood Warn", "Greenwood Trigger", "Greenwood Overrun", null, stationBehaviour, 20, 30);
      stationBehaviour.stopped.wav = "bell.wav";

      savePoint = 1;
      Sleep(1);
      Interface.SetObjective("Enter AFTON SUB, proceed to Robbins", "play.tga");
      Interface.SetAlert("Save point reached.\n\nPress Ctrl-S to save game.\nPress Ctrl-L to reload scenario from last save point", "save.tga", 10, Interface.Colour_White);
      Sleep(10);
    }

    ///////////////////////////////////////////////////////////////////////////
    //
    // TRAIN TO STOP AT ROBBINS.....
    //
    ///////////////////////////////////////////////////////////////////////////

    Sleep(4);

    Interface.SetObjective("Enter AFTON SUB, proceed to Robbins", "play.tga");

    Navigate.SetSignal("005", Signal.YELLOW, "");
    Navigate.SetSignal("007", Signal.YELLOW, "");

    // wait a while, and play some radio chatter.
    Sleep(10);
    Sleep(World.Play2DSound("103.wav") + 2);
    Sleep(World.Play2DSound("203.wav") + 4);
    World.Play2DSound("109.wav");

    // create a temporary consist at "Robbins Team"

    consist8 = World.CreateTrain(consist8Spec, "Robbins Team", false);
    consist8.ShowInConsistMenu(false);
    consist8.SetAutopilotMode(Train.CONTROL_SCRIPT);
    consist8.SetHandBrake(true);

    Navigate.Station(me, consist1, "Robbins", "Robbins Warn", "Robbins Trigger", "Robbins Overrun", "GPE", stationBehaviour, 20, 30);

    // we can safely delete the temp consists at greenwood now.

    World.DeleteTrain(consist4);
    World.DeleteTrain(consist6);
    World.DeleteTrain(consist7);

    ///////////////////////////////////////////////////////////////////////////
    //
    // TRAIN TO STOP AT STORMONT.....
    //
    ///////////////////////////////////////////////////////////////////////////

    Sleep(4);

    Interface.SetObjective("Proceed to Stormont", "play.tga");

    // create the AI train at stormont cross

    consist9 = World.CreateTrain(consist9Spec, "Stormont Cross", false);
    consist9.ShowInConsistMenu(false);
    consist9.SetAutopilotMode(Train.CONTROL_SCRIPT);

    // create a Schedule for the AI train

    Schedule schedule = new Schedule();

    schedule.OnAnnounce("STORMONT AI");
    schedule.TakeJunction("Stormont North", Junction.DIRECTION_LEFT);
    schedule.CompleteJunctions();
    schedule.Announce("STORMONT AI CLEAR");
    schedule.TakeJunction("Stormont South", Junction.DIRECTION_BACKWARD);
    schedule.TakeJunction("Robbins South", Junction.DIRECTION_RIGHT);
    schedule.DeleteTrain();

    consist9.RunSchedule(schedule, false, 0);

    // Lock some junctions from the user.
    Navigate.LockJunction("Stormont South", Junction.DIRECTION_LEFT, false);

    // get the user to Stormont station
    Navigate.Station(me, consist1, "Stormont", "Stormont Warn", "Stormont Trigger", "Stormont Overrun", "Robbins Warn", stationBehaviour, 20, 30);

    // we can delete the temp train a robbins
    World.DeleteTrain(consist8);

    ///////////////////////////////////////////////////////////////////////////
    //
    // WAIT FOR FREIGHT TO CROSS STORMONT YARD.....
    //
    ///////////////////////////////////////////////////////////////////////////

    Sleep(2);
    Timetable.Announce("STORMONT AI", GetId());
    Sleep(5);

    // wait a while, and play some radio chatter.
    Sleep(World.Play2DSound("103.wav") + 2);
    Sleep(World.Play2DSound("204.wav") + 3);
    World.Play2DSound("109.wav");

    // wait for the signal
    Navigate.Signal(me, consist1, "113", "Oncoming Freight train", "STORMONT AI", 0.0f, "STORMONT AI CLEAR", signalBehaviour);

    Sleep(5);
    World.Play2DSound("211.wav");
    Sleep(4);

    Navigate.LockJunction("Stormont North", Junction.DIRECTION_RIGHT, false);
    Sleep(2);

    Interface.SetObjective("Proceed to Highland Valley", "play.tga");

    ///////////////////////////////////////////////////////////////////////////
    //
    // MAKE YOUR WAY TO HIGHLAND VALLEY
    //
    ///////////////////////////////////////////////////////////////////////////

highlandValley:
    stationBehaviour.major = null;

    Navigate.LockJunction("Odlum South", Junction.DIRECTION_LEFT, false);
    Navigate.LockJunction("Odlum North", Junction.DIRECTION_RIGHT, false);
    Navigate.LockJunction("Wyenot Jct", Junction.DIRECTION_LEFT, false);
    Navigate.LockJunction("Highland Valley N", Junction.DIRECTION_LEFT, false);
    Navigate.LockJunction("Highland Valley S", Junction.DIRECTION_RIGHT, false);

    Navigate.SetSignal("115", Signal.YELLOW, "");

    consist10 = World.CreateTrain(consist10Spec, "Wyenot Consist", false);
    consist10.ShowInConsistMenu(false);
    consist10.SetAutopilotMode(Train.CONTROL_SCRIPT);
    consist10.SetHandBrake(true);

    Sleep(2.5);

    consist11 = World.CreateTrain(consist8Spec, "Thai Plant", false);
    consist11.ShowInConsistMenu(false);
    consist11.SetAutopilotMode(Train.CONTROL_SCRIPT);
    consist11.SetHandBrake(true);

    Sleep(2.5);

    consist12 = World.CreateTrain(consist12Spec, "Thai Plant 2", false);
    consist12.ShowInConsistMenu(false);
    consist12.SetAutopilotMode(Train.CONTROL_SCRIPT);
    consist12.SetHandBrake(true);

    // get the user to Highland valley station
    if(savePoint < 2)
    {
      Navigate.Station(me, consist1, "Highland Valley", "Highland Warn", "Highland Trigger", "Highland Overrun", "Stormont Warn", stationBehaviour, 20, 30);
      savePoint = 2;
      Sleep(1);
      Interface.SetObjective("Detach consist and turn loco", "play.tga");
      Interface.SetAlert("Save point reached.\n\nPress Ctrl-S to save game", "save.tga", 10, Interface.Colour_White);
      Sleep(10);
    }

    ///////////////////////////////////////////////////////////////////////////
    //
    // DECOUPLE AND TURN LOCO
    //
    ///////////////////////////////////////////////////////////////////////////

    // decouple your train
    consist1.SetDecouplingMask(Vehicle.COUPLE_BOTH);
    consist1.SetCouplingMask(Vehicle.COUPLE_BOTH);
    consist1.SetHandBrake(true);

    Sleep(1.0f);
    Interface.SetObjective("Detach your consist and proceed to the turntable.\n\nPress 'D' to enter decouple mode.  Mouse over coupler and click when decouple icon appears.", "play.tga");
    World.DeleteTrain(consist10);

    // turn your train around

    Sniff(tgTurntable, "Object", "Enter", true);

    wait()
    {
      on "Object", "Enter", msg :
      {
        // the object entering should be the palyers decoupled train.
        decoupledTrain = cast<Train> msg.src;
        if(decoupledTrain)
        {
          if(decoupledTrain.GetFrontmostLocomotive() and decoupledTrain.GetVehicles().size() == 1)
          {
            break;
          }
          else
          {
            Interface.SetObjective("Turntable suitable for light loco only.", "play.tga");
          }
        }
        continue;
      }
    }

    Navigate.OnTrigger(me, decoupledTrain, "Turntable Trigger", Navigate.TRIGGER_STOPPED);
    Interface.SetObjective("Turn loco and run around train.", "turn.tga");

    // wait for turntable to turn.

    Navigate.LockJunction("Highland Valley S", Junction.DIRECTION_LEFT, false);
    Navigate.LockJunction("Tie Plant Main", Junction.DIRECTION_LEFT, false);
    Navigate.LockJunction("Highland Valley N", Junction.DIRECTION_RIGHT, false);
    Navigate.SetSignal("22", Signal.YELLOW, "");
    Navigate.SetSignal("116", Signal.YELLOW, "");

    Sniff(tgTurntable, "Object", "Enter", false);

    Navigate.OnTrigger(me, decoupledTrain, "Turntable Trigger", Navigate.TRIGGER_LEAVE);
    Interface.SetObjectiveIcon("play.tga");

    ///////////////////////////////////////////////////////////////////////////
    //
    // RUN AROUND TRAIN
    //
    ///////////////////////////////////////////////////////////////////////////

    Interface.SetObjective("Run around train", "play.tga");
    Navigate.OnJunction(me, decoupledTrain, "Highland Valley N", Navigate.JUNCTION_INNERLEAVE);
    Navigate.SetSignal("116", Signal.AUTOMATIC, "");
    Navigate.LockJunction("Highland Valley N", Junction.DIRECTION_LEFT, false);

    ///////////////////////////////////////////////////////////////////////////
    //
    // ATTACH TO CONSIST.
    //
    ///////////////////////////////////////////////////////////////////////////

    decoupledTrain.GetFrontmostLocomotive().SetHasDriver(true);

    Interface.SetObjective("Enter Highland Valley yard, attach to consist, and stop at Highland Valley station.", "play.tga");

    on "Vehicle", "Coupled" :

    consist1 = decoupledTrain;
    consist1.SetHandBrake(false);
    consist1.SetDecouplingMask(Vehicle.COUPLE_NONE);
    consist1.SetCouplingMask(Vehicle.COUPLE_NONE);
        
    stationBehaviour.major = "Play2DSound";
    Navigate.Station(me, consist1, "Highland Valley", null, "Highland Trigger", null, null, stationBehaviour, 20, 30);
    Sleep(3);
    Interface.SetObjective("Proceed to Stormont", "play.tga");
    Navigate.SetSignal("118", Signal.GREEN, "");
    Navigate.OnJunction(me, decoupledTrain, "Highland Valley N", Navigate.JUNCTION_INNERLEAVE);
    Sleep(World.Play2DSound("104.wav") + 1.0);
    Sleep(World.Play2DSound("205.wav") + 2.0);
    World.Play2DSound("110.wav");

    ///////////////////////////////////////////////////////////////////////////
    //
    // TRAIN TRAVELS FROM HIGHLAND VALLEY TO STORMONT
    //
    ///////////////////////////////////////////////////////////////////////////

    Navigate.LockJunction("Wyenot Jct", Junction.DIRECTION_LEFT, false);
    Navigate.LockJunction("Odlum North", Junction.DIRECTION_RIGHT, false);
    Navigate.LockJunction("Odlum South", Junction.DIRECTION_LEFT, false);
    Navigate.LockJunction("Stormont North", Junction.DIRECTION_RIGHT, false);
    Navigate.LockJunction("Stormont South", Junction.DIRECTION_LEFT, false);

    stationBehaviour.major = "Play2DSound";
    Navigate.Station(me, consist1, "Stormont", "113 Trigger", "Stormont Trigger", "Stormont Overrun 1", "Highland Overrun", stationBehaviour, 20, 30);
    Interface.SetObjective("Proceed to Robbins.", "play.tga");
    stationBehaviour.major = null;

    World.DeleteTrain(consist11);
    World.DeleteTrain(consist12);

    ///////////////////////////////////////////////////////////////////////////
    //
    // TRAIN TRAVELS FROM STORMONT VALLEY TO ROBBINS
    //
    ///////////////////////////////////////////////////////////////////////////

    Navigate.LockJunction("Robbins South", Junction.DIRECTION_RIGHT, false);
    Navigate.LockJunction("Robbins Team track", Junction.DIRECTION_LEFT, false);
    Navigate.LockJunction("Robbins North", Junction.DIRECTION_RIGHT, false);

    //
    // create consist 13 at "Robbins North"
    //

    consist13 = World.CreateTrain(consist13Spec, "Robbins Cross", true);
    consist13.ShowInConsistMenu(false);

    // give the AI train a schedule
    schedule = new Schedule();

    schedule.OnAnnounce("ROBBINS AI");
    schedule.TakeJunction("Robbins North", Junction.DIRECTION_RIGHT);
    schedule.CompleteJunctions();
    schedule.Announce("ROBBINS AI CLEAR");
    schedule.TakeJunction("Robbins South", Junction.DIRECTION_BACKWARD);
    schedule.OnTrigger("Delete Consist13", true);
    schedule.DeleteTrain();

    consist13.RunSchedule(schedule, false, 0);

    Navigate.Station(me, consist1, "Robbins", "Robbins Warn 1", "Robbins Trigger", "Robbins Overrun 1", "Stormont Overrun", stationBehaviour, 20, 30);

    ///////////////////////////////////////////////////////////////////////////
    //
    // WAIT TO CROSS PASSENGER TRAIN AT ROBBINS
    //
    ///////////////////////////////////////////////////////////////////////////

    Sleep(3);

    signalBehaviour.warning.objective = "Continue to signal, wait to meet 7358";
    Navigate.Signal(me, consist1, "Robbins 106", "Oncoming train", "ROBBINS AI", 0.0f, "ROBBINS AI CLEAR", signalBehaviour);

    Sleep(4);
    World.Play2DSound("213.wav");
    Sleep(4);

    Navigate.LockJunction("Robbins North", Junction.DIRECTION_LEFT, false);

    Sleep(2);

    Interface.SetObjective("Proceed to Greenwood", "play.tga");

    ///////////////////////////////////////////////////////////////////////////
    //
    // MAKE YOUR WAY TO GREENWOOD STATION
    //
    ///////////////////////////////////////////////////////////////////////////

    Navigate.LockJunction("Cominco Coal North", Junction.DIRECTION_LEFT, false);
    Navigate.LockJunction("Cominco Loads North", Junction.DIRECTION_LEFT, false);
    Navigate.LockJunction("X1ANW", Junction.DIRECTION_LEFT, false);
    Navigate.LockJunction("X1ASE", Junction.DIRECTION_LEFT, false);
    Navigate.LockJunction("Greenwood Terminal", Junction.DIRECTION_LEFT, false);
    Navigate.LockJunction("Afton Branch", Junction.DIRECTION_LEFT, false);

    Navigate.SetSignal("114", Signal.YELLOW, "");
    Navigate.SetSignal("098", Signal.YELLOW, "");
    
    Navigate.OnTrigger(me, consist1, "GTHO", Navigate.TRIGGER_ENTER);

    consist14 = World.CreateTrain(consist14Spec, "GTHO3", true);
    consist14.ShowInConsistMenu(false);

    schedule = new Schedule();

    schedule.OnTrigger("Start Reverse", true);
    schedule.DeleteTrain();

    consist14.RunSchedule(schedule, false, 0);    

    // stop at the station

    stationBehaviour.stopped.objective = "Wait for passengers alight";

    Navigate.Station(me, consist1, "Greenwood", "Greenwood Warn 1", "Greenwood Trigger", "Greenwood Overrun 1", null, stationBehaviour, 10, 20);

    ///////////////////////////////////////////////////////////////////////////
    //
    // SCENARIO DONE, DISPLAY THE RESULTS
    //
    ///////////////////////////////////////////////////////////////////////////

    Interface.LogResult("Scenario complete.  You scored " + Interface.GetScore() + " points.");
    Interface.SetObjective("Report to foreman for further work orders.\n\nScenario complete.  You scored " + Interface.GetScore() + " points.", "tick.tga");
    Interface.SetResults();
    World.EndScenario(8.0f);
  }
};
